pytilities.stringifiable.Stringifiable

Package pytilities :: Module stringifiable :: Class Stringifiable |
[hide private]
[frames] | no frames]

# Class Stringifiable

source code

    object --+
             |
            Stringifiable

Mixin that provides a reasonable default __str__.

Instance Methods | [hide private]
__str__(self) Returns the class name | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __str__(self) (Informal representation operator) | source code
Returns the class name Overrides: object.__str__